package com.jiuqi.util;

import java.text.DecimalFormat;
import java.text.FieldPosition;
import java.text.NumberFormat;
import java.text.ParsePosition;

/* loaded from: com_jiuqi_util.jar:com/jiuqi/util/ChineseCurrencyFormat.class */
public class ChineseCurrencyFormat extends NumberFormat {
    private static final int level_number_count = 4;
    private static final int max_int_count = 20;
    private static final String zero_money_str = "零元整";
    private static final String negative_str = "负";
    private String prefix;
    private String suffix;
    private boolean startZero;
    private static final char[] numberChars = {38646, 22777, 36144, 21441, 32902, 20237, 38470, 26578, 25420, 29590};
    private static final char[] numberUnits = {25342, 20336, 20191, 19975};
    private static final char[] numberLevels = {19975, 20159, 20806};
    private static final char[] moneyUnits = {20803, 35282, 20998};

    public ChineseCurrencyFormat() {
        this.startZero = false;
        this.prefix = null;
        this.suffix = null;
    }

    public ChineseCurrencyFormat(String prefix, String suffix) {
        this.startZero = false;
        this.prefix = prefix;
        this.suffix = suffix;
    }

    public String getPrefix() {
        return this.prefix;
    }

    public void setPrefix(String value) {
        this.prefix = value;
    }

    public String getSuffix() {
        return this.suffix;
    }

    public void setSuffix(String value) {
        this.suffix = value;
    }

    @Override // java.text.NumberFormat
    public Number parse(String source, ParsePosition parsePosition) {
        return null;
    }

    private String convertSimple(String number) {
        boolean z;
        StringBuffer buffer = new StringBuffer();
        boolean prevZero = false;
        boolean started = false;
        int cnt = 0;
        for (int i = number.length() - 1; i >= 0; i--) {
            char ch = number.charAt(i);
            if (ch == '0') {
                z = true;
            } else {
                if (started && prevZero) {
                    buffer.insert(0, numberChars[0]);
                }
                if (cnt > 0) {
                    buffer.insert(0, numberUnits[cnt - 1]);
                }
                buffer.insert(0, numberChars[ch - '0']);
                started = true;
                z = false;
            }
            prevZero = z;
            cnt++;
        }
        this.startZero = prevZero;
        return buffer.toString();
    }

    protected void format(String number, StringBuffer toAppendTo) {
        String intString;
        String decString;
        if (number == null || number.length() == 0) {
            return;
        }
        if (number.charAt(0) == '-') {
            number = number.substring(1);
            toAppendTo.append(negative_str);
        }
        if (number.equals(JqLib.SQL_FALSE)) {
            toAppendTo.append(zero_money_str);
            return;
        }
        int pointPos = number.indexOf(46);
        if (pointPos < 0) {
            pointPos = number.length();
        }
        if (pointPos == 1 && number.charAt(0) == '0') {
            intString = null;
        } else {
            if (pointPos > max_int_count) {
                toAppendTo.append("数值过大，转化失败");
                return;
            }
            int levelCount = ((pointPos + 4) - 1) / 4;
            if (levelCount > 0) {
                String[] levelStrs = new String[levelCount];
                boolean[] zeroStarts = new boolean[levelCount];
                for (int i = 0; i < levelCount; i++) {
                    int end = pointPos - (4 * i);
                    int start = end - 4 < 0 ? 0 : end - 4;
                    String subVal = convertSimple(number.substring(start, end));
                    levelStrs[i] = "".equals(subVal) ? null : subVal;
                    zeroStarts[i] = this.startZero;
                }
                StringBuffer buffer = new StringBuffer();
                boolean started = false;
                if (levelStrs[0] != null) {
                    buffer.insert(0, levelStrs[0]);
                    started = true;
                }
                if (levelCount >= 2) {
                    if (levelStrs[1] != null) {
                        if (started && zeroStarts[0]) {
                            buffer.insert(0, numberChars[0]);
                        }
                        buffer.insert(0, numberLevels[0]);
                        buffer.insert(0, levelStrs[1]);
                        started = true;
                    }
                    if (levelCount >= 3) {
                        if (levelStrs[2] != null) {
                            if (started && levelStrs[1] == null) {
                                buffer.insert(0, numberChars[0]);
                            } else if (started && levelStrs[1] != null && zeroStarts[1]) {
                                buffer.insert(0, numberChars[0]);
                            }
                            buffer.insert(0, numberLevels[1]);
                            buffer.insert(0, levelStrs[2]);
                            started = true;
                        }
                        if (levelCount >= 4 && levelStrs[3] != null) {
                            if (levelStrs[2] == null && started && levelStrs[1] == null) {
                                buffer.insert(0, numberChars[0]);
                            }
                            if (levelStrs[2] == null) {
                                buffer.insert(0, numberLevels[1]);
                            }
                            buffer.insert(0, numberLevels[0]);
                            buffer.insert(0, levelStrs[3]);
                            started = true;
                        }
                        if (levelCount >= 5 && levelStrs[4] != null) {
                            if (started && levelStrs[4] == null && levelStrs[3] == null) {
                                buffer.insert(0, numberChars[0]);
                            }
                            if (levelStrs[4] != null) {
                                buffer.insert(0, numberLevels[2]);
                                buffer.insert(0, levelStrs[4]);
                            }
                        }
                    }
                }
                intString = buffer.toString();
            } else {
                intString = null;
            }
        }
        if (pointPos >= number.length() - 1) {
            decString = null;
        } else {
            char p1 = number.charAt(pointPos + 1);
            char p2 = number.length() - 1 >= pointPos + 2 ? number.charAt(pointPos + 2) : '0';
            if (p1 == '0' && p2 == '0') {
                decString = null;
            } else {
                StringBuffer buffer2 = new StringBuffer();
                if (p1 == '0') {
                    buffer2.append(numberChars[0]);
                    buffer2.append(numberChars[p2 - '0']);
                    buffer2.append(moneyUnits[2]);
                } else if (p2 == '0') {
                    buffer2.append(numberChars[p1 - '0']);
                    buffer2.append(moneyUnits[1]);
                } else {
                    buffer2.append(numberChars[p1 - '0']);
                    buffer2.append(moneyUnits[1]);
                    buffer2.append(numberChars[p2 - '0']);
                    buffer2.append(moneyUnits[2]);
                }
                decString = buffer2.toString();
            }
        }
        if (intString == null && decString == null) {
            toAppendTo.append(zero_money_str);
            return;
        }
        if (intString == null) {
            toAppendTo.append(decString);
        } else {
            if (decString == null) {
                toAppendTo.append(String.valueOf(intString) + "元整");
                return;
            }
            toAppendTo.append(intString);
            toAppendTo.append("元");
            toAppendTo.append(decString);
        }
    }

    @Override // java.text.NumberFormat
    public StringBuffer format(double number, StringBuffer toAppendTo, FieldPosition pos) {
        if (this.prefix != null) {
            toAppendTo.append(this.prefix);
        }
        NumberFormat fmt = new DecimalFormat("0.##");
        format(fmt.format(number), toAppendTo);
        if (this.suffix != null) {
            toAppendTo.append(this.suffix);
        }
        return toAppendTo;
    }

    @Override // java.text.NumberFormat
    public StringBuffer format(long number, StringBuffer toAppendTo, FieldPosition pos) {
        if (this.prefix != null) {
            toAppendTo.append(this.prefix);
        }
        format(Long.toString(number), toAppendTo);
        if (this.suffix != null) {
            toAppendTo.append(this.suffix);
        }
        return toAppendTo;
    }
}
